==> nextcloud-26.0.13.zip: nextcloud/apps/settings/l10n/lv.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Privāts",
    "Local" : "Lokāls",
    "Federated" : "Federated",
    "Verify" : "Verificēt",
    "Unable to change password" : "Nav iespējams nomainīt paroli",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "Groups" : "Grupas",
    "Group list is empty" : "Grupu saraksts ir tukšš",
    "Unable to retrieve the group list" : "Nevarēja saņemt grupu sarakstu",
    "You successfully logged in using two-factor authentication (%1$s)" : "Esat veiksmīgi pieteicies, izmantojot divpakāpju autentifikācija (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Pieteikšanās mēģinājums, izmantojot divpakāpju autentifikāciju neizdevās (%1$s)",
    "Settings" : "Iestatījumi",
    "Wrong password" : "Nepareiza parole",
    "Saved" : "Saglabāts",
    "Authentication error" : "Autentifikācijas kļūda",
    "Wrong admin recovery password. Please check the password and try again." : "Nepareiza administratora atjaunošanas parole. Lūdzu pārbaudiet paroli un mēģiniet vēlreiz.",
    "Administrator documentation" : "Administratora dokumentācija",
    "User documentation" : "Lietotāja dokumentācija",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Radās kļūda, nosūtot e-pastu. Lūdzu, pārskatiet savus iestatījumus. (Kļūda: %s)",
    "Invalid account" : "Nederīgs konts",
    "Invalid mail address" : "Nepareiza e-pasta adrese",
    "Settings saved" : "Iestatījumi saglabāti",
    "Unable to change full name" : "Nav iespējams nomainīt jūsu pilno vārdu",
    "Unable to change email address" : "Nevar mainīt e-pasta adresi",
    "Your %s account was created" : "Konts %s ir izveidots",
    "Apps" : "Lietotnes",
    "Personal" : "Personīgs",
    "Administration" : "Administrēšana",
    "Users" : "Lietotāji",
    "Additional settings" : "Papildu iestatījumi",
    "Administration privileges" : "Administrēšanas privilēģijas",
    "Sharing" : "Koplietošana",
    "Availability" : "Pieejamība",
    "Calendar" : "Kalendārs",
    "Personal info" : "Personiskā informācija",
    "Email server" : "E-pasta serveris",
    "Security & setup warnings" : "Drošības un iestatījumu brīdinājumi",
    "Unlimited" : "Neierobežota",
    "Disabled" : "Atspējots",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nešķiet pareizi uzstādīts lai veiktu sistēmas vides mainīgo vaicājumus. Tests ar getenv(\"PATH\") atgriež tikai tukšu atbildi.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Ir iespējots tikai lasāma konfigurācija. Tas neatļauj iestatīt un mainīt dažas konfigurācijas caur tīmekļa interfeisu. Šī datne būs manuāli jāpārveido par rakstāmu, pirms katra atjauninājuma instalēšanas.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Jūsu datubāze neiet ar \"READ COMMITED\" transakciju izolācijas līmeni. Tas var radīt problēmas kad vairākas darbības tiek veiktas pararēli.",
    "Nextcloud settings" : "Nextcloud iestatījumi",
    "None" : "Nav",
    "Allow apps to use the Share API" : "Ļaut programmām izmantot koplietošanas API",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Allow sharing with groups" : "Atļaut koplietošanu ar grupām",
    "Restrict users to only share with users in their groups" : "Ierobežot lietotājiem koplietot tikai ar lietotājiem savās grupās",
    "Allow public uploads" : "Atļaut publisko augšupielādi",
    "Enforce password protection" : "Ieviest paroles aizsardzību",
    "Enforce expiration date" : "Uzspiest beigu termiņu",
    "Limit to groups" : "Grupu ierobežojums",
    "Save changes" : "Saglabāt izmaiņas",
    "Remove" : "Izņemt",
    "Disable" : "Deaktivēt",
    "Icon" : "Ikona",
    "Name" : "Vārds",
    "Version" : "Versija",
    "Actions" : "Darbības",
    "No apps found for your version" : "Neatrada lietotnes jūsu versijai",
    "Description" : "Apraksts",
    "Details" : "Detaļas",
    "All" : "Visi",
    "No results" : "Nav rezultātu",
    "Update to {version}" : "Atjaunināts uz {version}",
    "Categories" : "Kategorijas",
    "Resources" : "Resursi",
    "Documentation" : "Dokumentācija",
    "Report a bug" : "Ziņot par kļūdu",
    "Rate" : "Vērtēt",
    "Visit website" : "Apmeklējiet vietni",
    "Admin documentation" : "Administratora dokumentācija",
    "Developer documentation" : "Izstrādātāja dokumentācija",
    "Changelog" : "Izmaiņu žurnāls",
    "Device settings" : "Ierīces iestatījumi",
    "Rename" : "Pārsaukt",
    "Revoke" : "Atsaukt",
    "Google Chrome for Android" : "Google Chrome for Android",
    "This session" : "Šajā sesijā",
    "Device" : "Ierīce",
    "Last activity" : "Pēdējās darbības",
    "App name" : "Lietotnes nosaukums",
    "Create new app password" : "Izveidot jaunu lietotnes paroli",
    "Login" : "Autorizēties",
    "Password" : "Parole",
    "Profile" : "Profils",
    "Enable" : "Aktivēt",
    "Server-side encryption" : "Servera šifrēšana",
    "Enable server-side encryption" : "Ieslēgt servera šifrēšanu",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifrēšana vien negarantē sistēmas drošību. Skatiet dokumentāciju, lai iegūtu papildinformāciju par šifrēšanas lietotnes izmantošanu un atbalstītajiem izmantošanas veidiem.",
    "Be aware that encryption always increases the file size." : "Jāapzinās, ka šifrēšanas vienmēr palielina datnes lielumu.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Vienmēr ir ieteicams regulāri veidot dublējumkopijas datu šifrēšanas gadījumam, pārliecinieties, lai dublētu, šifrēšanas atslēgas ir kopā ar jūsu datiem.",
    "This is the final warning: Do you really want to enable encryption?" : "Šis ir pēdējais brīdinājums: vai tiešām vēlaties iespējot šifrēšanu?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nav ielādēts šifrēšanas moduļis, lūdzu, aktivizējiet šifrēšanas moduli lietotņu izvēlnē.",
    "Select default encryption module:" : "Atlasiet noklusēto šifrēšanas moduli:",
    "Cancel" : "Atcelt",
    "Confirm" : "Apstiprināt",
    "Submit" : "Iesniegt",
    "Remove group" : "Noņemt grupu",
    "Current password" : "Pašreizējā parole",
    "New password" : "Jauna parole",
    "Change password" : "Mainīt paroli",
    "No email address set" : "Nav norādīts e-pasts",
    "Help translate" : "Palīdzi tulkot",
    "Your phone number" : "Jūsu tālruņa numurs",
    "Your website" : "Jūsu mājaslapa",
    "Add" : "Pievienot",
    "Create" : "Izveidot",
    "Change" : "Mainīt",
    "Delete" : "Dzēst",
    "Display name" : "Ekrāna vārds",
    "Email" : "E-pasts",
    "Quota" : "Apjoms",
    "Language" : "Valoda",
    "Avatar" : "Profila attēls",
    "Username" : "Lietotājvārds",
    "Group admin for" : "Admin grupa",
    "Storage location" : "Krātuves atrašanās vieta",
    "Last login" : "Pēdējā pieteikšanās",
    "Delete account" : "Dzēst kontu",
    "Done" : "Pabeigts",
    "Edit" : "Rediģēt",
    "Visibility" : "Redzamība",
    "Show last login" : "Rādīt pēdējo autorizāciju",
    "Send email" : "Sūtīt e-pastu",
    "Default quota" : "Apjoms pēc noklusējuma",
    "Admins" : "Admins",
    "Group name" : "Grupas nosaukums",
    "Sending…" : "Sūta …",
    "Email sent" : "Vēstule nosūtīta",
    "Location" : "Vieta",
    "Profile picture" : "Profila attēls",
    "About" : "Par",
    "Full name" : "Pilns vārds",
    "Phone number" : "Tālruņa numurs",
    "Website" : "Mājaslapa",
    "Updates" : "Atjauninājumi",
    "Hide" : "Slēpt",
    "Never" : "Nekad",
    "Forum" : "Forums",
    "SSL" : "SSL",
    "Open documentation" : "Atvērt dokumentāciju",
    "Send mode" : "Sūtīšanas metode",
    "Encryption" : "Šifrēšana",
    "From address" : "No adreses",
    "Server address" : "Servera adrese",
    "Port" : "Ports",
    "Authentication" : "Autentifikācija",
    "Authentication required" : "Nepieciešama autentifikācija",
    "Credentials" : "Akreditācijas dati",
    "SMTP Password" : "SMTP parole",
    "Save" : "Saglabāt",
    "All checks passed." : "Visas pārbaudes veiksmīgas.",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Izstrādātās {communityopen}Nextcloud kopiena {linkclose},  {githubopen} avota kods {linkclose} licencēts saskaņā ar {licenseopen}AGPL{linkclose}.",
    "No user supplied" : "Nav norādīts lietotājs",
    "Federated Cloud Sharing" : "Federatīva mākoņkoplietošana",
    "Invalid user" : "Nepareizs lietotājs",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "iPhone" : "iPhone",
    "Sync client - {os}" : "Sync klients - {os}",
    "Use the credentials below to configure your app or device." : "Izmantot akreditācijas datus, lai konfigurētu savu lietotni vai ierīci.",
    "For security reasons this password will only be shown once." : "Drošības apsvērumu dēļ šī parole, tiks parādīta tikai vienreiz.",
    "Copied!" : "Nokopēts!",
    "Copy" : "Kopēt",
    "png or jpg, max. 20 MB" : "png vai jpg, max. 20 MB",
    "Your email address" : "Jūsu e-pasta adrese",
    "Add group" : "Pievienot grupu",
    "Active users" : "Aktīvie lietotāji",
    "Send email to new user" : "Sūtīt e-pastu jaunajam lietotājam",
    "Not saved" : "Nav saglabāts",
    "Twitter" : "Twitter",
    "SMTP Username" : "SMTP lietotājvārds",
    "Set default expiration date" : "Iestatīt noklusējuma beigu datumu",
    "Exclude groups from sharing" : "Izslēgt grupas no koplietošanas"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-29.0.2.zip: nextcloud/apps/settings/l10n/lv.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Privāts",
    "Local" : "Lokāls",
    "Federated" : "Federated",
    "Verify" : "Verificēt",
    "Unable to change password" : "Nav iespējams nomainīt paroli",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Viduvēja parole",
    "Good password" : "Laba parole",
    "Strong password" : "Spēcīga parole",
    "Groups" : "Grupas",
    "Group list is empty" : "Grupu saraksts ir tukšš",
    "Unable to retrieve the group list" : "Nevarēja saņemt grupu sarakstu",
    "{actor} changed your password" : "{actor] nomainīja Tavu paroli",
    "You changed your password" : "Tu nomainīji savu paroli",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Tu pārdēvēji lietotnes paroli \"{token}\" uz \"{newToken}\"",
    "Security" : "Drošība",
    "You successfully logged in using two-factor authentication (%1$s)" : "Esat veiksmīgi pieteicies, izmantojot divpakāpju autentifikācija (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Pieteikšanās mēģinājums ar divpakāpju autentifikāciju neizdevās (%1$s)",
    "Settings" : "Iestatījumi",
    "Wrong password" : "Nepareiza parole",
    "Saved" : "Saglabāts",
    "Authentication error" : "Autentifikācijas kļūda",
    "Wrong admin recovery password. Please check the password and try again." : "Nepareiza administratora atjaunošanas parole. Lūdzu pārbaudiet paroli un mēģiniet vēlreiz.",
    "Administrator documentation" : "Administratora dokumentācija",
    "User documentation" : "Lietotāja dokumentācija",
    "Invalid SMTP password." : "Nederīga SMTP parole",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Radās kļūda, nosūtot e-pastu. Lūdzu, pārskatiet savus iestatījumus. (Kļūda: %s)",
    "Invalid account" : "Nederīgs konts",
    "Invalid mail address" : "Nepareiza e-pasta adrese",
    "Settings saved" : "Iestatījumi saglabāti",
    "Unable to change full name" : "Nav iespējams nomainīt jūsu pilno vārdu",
    "Unable to change email address" : "Nevar mainīt e-pasta adresi",
    "Your %s account was created" : "Konts %s ir izveidots",
    "Apps" : "Lietotnes",
    "Personal" : "Personīgs",
    "Administration" : "Administrēšana",
    "Users" : "Lietotāji",
    "Additional settings" : "Papildu iestatījumi",
    "Administration privileges" : "Administrēšanas privilēģijas",
    "Sharing" : "Koplietošana",
    "Availability" : "Pieejamība",
    "Calendar" : "Kalendārs",
    "Personal info" : "Personiskā informācija",
    "Mobile & desktop" : "Tālrunis un darbvirsma",
    "Email server" : "E-pasta serveris",
    "Security & setup warnings" : "Drošības un iestatījumu brīdinājumi",
    "Unlimited" : "Neierobežota",
    "Disabled" : "Atspējots",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nešķiet pareizi uzstādīts lai veiktu sistēmas vides mainīgo vaicājumus. Tests ar getenv(\"PATH\") atgriež tikai tukšu atbildi.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Ir iespējots tikai lasāma konfigurācija. Tas neatļauj iestatīt un mainīt dažas konfigurācijas caur tīmekļa interfeisu. Šī datne būs manuāli jāpārveido par rakstāmu, pirms katra atjauninājuma instalēšanas.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Jūsu datubāze neiet ar \"READ COMMITED\" transakciju izolācijas līmeni. Tas var radīt problēmas kad vairākas darbības tiek veiktas pararēli.",
    "Nextcloud settings" : "Nextcloud iestatījumi",
    "None" : "Nav",
    "Allow apps to use the Share API" : "Ļaut programmām izmantot koplietošanas API",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Allow sharing with groups" : "Atļaut koplietošanu ar grupām",
    "Restrict users to only share with users in their groups" : "Ierobežot lietotājiem koplietot tikai ar lietotājiem savās grupās",
    "Allow public uploads" : "Atļaut publisko augšupielādi",
    "Enforce password protection" : "Ieviest paroles aizsardzību",
    "Enforce expiration date" : "Uzspiest beigu termiņu",
    "Privacy settings for sharing" : "Kopīgošanas privātuma iestatījumi",
    "Limit to groups" : "Ierobežot kopām",
    "Save changes" : "Saglabāt izmaiņas",
    "Remove" : "Izņemt",
    "Disable" : "Deaktivēt",
    "Icon" : "Ikona",
    "Name" : "Vārds",
    "Version" : "Versija",
    "Actions" : "Darbības",
    "No apps found for your version" : "Neatrada lietotnes jūsu versijai",
    "Description" : "Apraksts",
    "Details" : "Detaļas",
    "All" : "Visi",
    "No results" : "Nav rezultātu",
    "Update to {version}" : "Atjaunināts uz {version}",
    "Categories" : "Kategorijas",
    "Resources" : "Resursi",
    "Documentation" : "Dokumentācija",
    "Report a bug" : "Ziņot par kļūdu",
    "Rate" : "Vērtēt",
    "Visit website" : "Apmeklējiet vietni",
    "Admin documentation" : "Administratora dokumentācija",
    "Developer documentation" : "Izstrādātāja dokumentācija",
    "Changelog" : "Izmaiņu žurnāls",
    "Device settings" : "Ierīces iestatījumi",
    "Rename" : "Pārsaukt",
    "Revoke" : "Atsaukt",
    "Google Chrome for Android" : "Google Chrome for Android",
    "This session" : "Šajā sesijā",
    "Device" : "Ierīce",
    "Last activity" : "Pēdējās darbības",
    "Devices & sessions" : "Ierīces un sesijas",
    "App name" : "Lietotnes nosaukums",
    "Create new app password" : "Izveidot jaunu lietotnes paroli",
    "New app password" : "Jauna lietotnes parole",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Zemāk esošie piekļuves dati jāizmanto, lai konfigurētu lietotni vai ierīci. Drošības iemeslu dēļ šī parole tiks parādīta tikai vienu reizi.",
    "Login" : "Autorizēties",
    "Password" : "Parole",
    "Show QR code for mobile apps" : "Parādīt kvadrātkodu tālruņa lietotnēm",
    "Profile" : "Profils",
    "Enable" : "Aktivēt",
    "Server-side encryption" : "Servera šifrēšana",
    "Enable server-side encryption" : "Ieslēgt servera šifrēšanu",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifrēšana vien negarantē sistēmas drošību. Skatiet dokumentāciju, lai iegūtu papildinformāciju par šifrēšanas lietotnes izmantošanu un atbalstītajiem izmantošanas veidiem.",
    "Be aware that encryption always increases the file size." : "Jāapzinās, ka šifrēšanas vienmēr palielina datnes lielumu.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Vienmēr ir ieteicams regulāri veidot dublējumkopijas datu šifrēšanas gadījumam, pārliecinieties, lai dublētu, šifrēšanas atslēgas ir kopā ar jūsu datiem.",
    "This is the final warning: Do you really want to enable encryption?" : "Šis ir pēdējais brīdinājums: vai tiešām iespējot šifrēšanu?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nav ielādēts šifrēšanas moduļis, lūdzu, aktivizējiet šifrēšanas moduli lietotņu izvēlnē.",
    "Select default encryption module:" : "Atlasiet noklusēto šifrēšanas moduli:",
    "Cancel" : "Atcelt",
    "Confirm" : "Apstiprināt",
    "Submit" : "Iesniegt",
    "Remove group" : "Noņemt grupu",
    "Current password" : "Pašreizējā parole",
    "New password" : "Jauna parole",
    "Change password" : "Mainīt paroli",
    "No email address set" : "Nav norādīts e-pasts",
    "Help translate" : "Palīdzi tulkot",
    "Your phone number" : "Jūsu tālruņa numurs",
    "Your website" : "Jūsu mājaslapa",
    "Add" : "Pievienot",
    "Create" : "Izveidot",
    "Change" : "Mainīt",
    "Delete" : "Dzēst",
    "Display name" : "Ekrāna vārds",
    "Email" : "E-pasts",
    "Quota" : "Apjoms",
    "Language" : "Valoda",
    "Scroll to load more rows" : "Ritināt, lai ielādētu vairāk rindu",
    "Avatar" : "Profila attēls",
    "Group admin for" : "Admin grupa",
    "Storage location" : "Krātuves atrašanās vieta",
    "Last login" : "Pēdējā pieteikšanās",
    "Account actions" : "Konta darbības",
    "Delete account" : "Dzēst kontu",
    "Done" : "Pabeigts",
    "Edit" : "Labot",
    "Visibility" : "Redzamība",
    "Show last login" : "Rādīt pēdējo autorizāciju",
    "Send email" : "Sūtīt e-pastu",
    "Default quota" : "Apjoms pēc noklusējuma",
    "Admins" : "Admins",
    "Group name" : "Grupas nosaukums",
    "Sending…" : "Sūta …",
    "Email sent" : "Vēstule nosūtīta",
    "Location" : "Vieta",
    "Profile picture" : "Profila attēls",
    "About" : "Par",
    "Full name" : "Pilns vārds",
    "Phone number" : "Tālruņa numurs",
    "Website" : "Mājaslapa",
    "Updates" : "Atjauninājumi",
    "Hide" : "Slēpt",
    "Never" : "Nekad",
    "Forum" : "Forums",
    "Nextcloud help & privacy resources" : "Nextcloud palīdzība un privātuma līdzekļi",
    "Privacy policy" : "Privātuma politika",
    "SSL" : "SSL",
    "Open documentation" : "Atvērt dokumentāciju",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Ir svarīgi iestatīt šo serveri, lai varētu nosūtīt e-pasta ziņojumus, piemēram, paroles atiestatīšanai un paziņojumus.",
    "Send mode" : "Sūtīšanas metode",
    "Encryption" : "Šifrēšana",
    "From address" : "No adreses",
    "Server address" : "Servera adrese",
    "Port" : "Ports",
    "Authentication" : "Autentifikācija",
    "Authentication required" : "Nepieciešama autentifikācija",
    "Credentials" : "Akreditācijas dati",
    "SMTP Password" : "SMTP parole",
    "Save" : "Saglabāt",
    "All checks passed." : "Visas pārbaudes veiksmīgas.",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Izstrādātās {communityopen}Nextcloud kopiena {linkclose},  {githubopen} avota kods {linkclose} licencēts saskaņā ar {licenseopen}AGPL{linkclose}.",
    "No user supplied" : "Nav norādīts lietotājs",
    "Federated Cloud Sharing" : "Federatīva mākoņkoplietošana",
    "Invalid user" : "Nepareizs lietotājs",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "iPhone" : "iPhone",
    "Sync client - {os}" : "Sync klients - {os}",
    "Use the credentials below to configure your app or device." : "Izmantot akreditācijas datus, lai konfigurētu savu lietotni vai ierīci.",
    "For security reasons this password will only be shown once." : "Drošības apsvērumu dēļ šī parole, tiks parādīta tikai vienreiz.",
    "Username" : "Lietotājvārds",
    "Copied!" : "Nokopēts!",
    "Copy" : "Kopēt",
    "Your email address" : "Jūsu e-pasta adrese",
    "Add group" : "Pievienot grupu",
    "Active users" : "Aktīvie lietotāji",
    "Send email to new user" : "Sūtīt e-pastu jaunajam lietotājam",
    "Not saved" : "Nav saglabāts",
    "Twitter" : "Twitter",
    "SMTP Username" : "SMTP lietotājvārds",
    "Set default expiration date" : "Iestatīt noklusējuma beigu datumu",
    "Exclude groups from sharing" : "Izslēgt grupas no koplietošanas"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
